pub struct RawMeta {
pub version: u32,
pub created: Option<String>,
pub labels: Option<BTreeMap<String, String>>,
pub layers: IndexMap<String, String>,
pub mapping: IndexMap<String, String>,
pub ordered: Option<bool>,
}Expand description
Grouping of metadata about an object.
Fields
version: u32The metadata format version. Should be set to 1.
created: Option<String>The image creation timestamp. Format is YYYY-MM-DDTHH:MM:SSZ. Should be synced with the label io.container.image.created.
labels: Option<BTreeMap<String, String>>Top level labels, to be prefixed to the ones with –label Applied to both the outer config annotations and the inner config labels.
layers: IndexMap<String, String>The output layers ordered. Provided as an ordered mapping of a unique machine readable strings to a human readable name (e.g., the layer contents). The human-readable name is placed in a layer annotation.
mapping: IndexMap<String, String>The layer contents. The key is an ostree hash and the value is the machine readable string of the layer the hash belongs to. WARNING: needs to contain all ostree hashes in the input commit.
ordered: Option<bool>Whether the mapping is ordered. If true, the output tar stream of the layers will reflect the order of the hashes in the mapping. Otherwise, a deterministic ordering will be used regardless of mapping order. Potentially useful for optimizing zstd:chunked compression. WARNING: not currently supported.